@@ -3,14 +3,14 @@ package Specio::Library::Builtins;
 use strict;
 use warnings;
 
-our $VERSION = '0.44';
+our $VERSION = '0.50';
 
 use parent 'Specio::Exporter';
 
 use List::Util 1.33 ();
-use overload     ();
-use re           ();
-use Scalar::Util ();
+use overload        ();
+use re              ();
+use Scalar::Util    ();
 use Specio::Constraint::Parameterizable;
 use Specio::Declare;
 use Specio::Helpers ();
@@ -108,7 +108,6 @@ EOF
     }
 );
 
-my $value_type = t('Value');
 declare(
     'Num',
     parent => t('Str'),
@@ -148,14 +147,24 @@ declare(
         defined( %s )
         && !ref( %s )
         && (
-               do { ( my $val1 = %s ) =~ /\A-?[0-9]+(?:[Ee]\+?[0-9]+)?\z/ }
+               do {
+                   my $val1 = %s;
+                   $val1 =~ /\A-?[0-9]+(?:[Ee]\+?[0-9]+)?\z/
+                   && $val1 == int($val1)
+               }
            )
     )
     ||
     (
         Scalar::Util::blessed( %s )
         && defined overload::Method( %s, '0+' )
-        && do { ( my $val2 = %s + 0 ) =~ /\A-?[0-9]+(?:[Ee]\+?[0-9]+)?\z/ }
+        && (
+               do {
+                   my $val2 = %s + 0;
+                   $val2 =~ /\A-?[0-9]+(?:[Ee]\+?[0-9]+)?\z/
+                   && $val2 == int($val2)
+               }
+           )
     )
 )
 EOF
@@ -337,7 +346,7 @@ EOF
         parent     => t('Ref'),
         inline     => sub { $base_scalarref_check->( $_[1] ) },
         parameterized_inline_generator => sub {
-            my $self      = shift;
+            shift;
             my $parameter = shift;
             my $val       = shift;
 
@@ -375,7 +384,7 @@ EOF
         parent     => t('Ref'),
         inline     => sub { $base_arrayref_check->( $_[1] ) },
         parameterized_inline_generator => sub {
-            my $self      = shift;
+            shift;
             my $parameter = shift;
             my $val       = shift;
 
@@ -414,7 +423,7 @@ EOF
         parent     => t('Ref'),
         inline     => sub { $base_hashref_check->( $_[1] ) },
         parameterized_inline_generator => sub {
-            my $self      = shift;
+            shift;
             my $parameter = shift;
             my $val       = shift;
 
@@ -434,7 +443,7 @@ declare(
     parent                         => t('Item'),
     inline                         => sub {'1'},
     parameterized_inline_generator => sub {
-        my $self      = shift;
+        shift;
         my $parameter = shift;
         my $val       = shift;
 
@@ -460,7 +469,7 @@ Specio::Library::Builtins - Implements type constraint objects for Perl's built-
 
 =head1 VERSION
 
-version 0.44
+version 0.50
 
 =head1 DESCRIPTION
 
@@ -535,8 +544,8 @@ Accepts any reference.
 
 =head2 ScalarRef (of `a)
 
-Accepts a scalar reference or an object which overloads scalar
-dereferencing. If parameterized, the dereferenced value must be of type C<`a>.
+Accepts a scalar reference or an object which overloads scalar dereferencing.
+If parameterized, the dereferenced value must be of type C<`a>.
 
 =head2 ArrayRef (of `a)
 
@@ -550,13 +559,12 @@ parameterized, the values in the hashref must be of type C<`a>.
 
 =head2 CodeRef
 
-Accepts a code (sub) reference or an object which overloads code
-dereferencing.
+Accepts a code (sub) reference or an object which overloads code dereferencing.
 
 =head2 RegexpRef
 
-Accepts a regex object created by C<qr//> or an object which overloads
-regex interpolation.
+Accepts a regex object created by C<qr//> or an object which overloads regex
+interpolation.
 
 =head2 GlobRef
 
@@ -564,9 +572,9 @@ Accepts a glob reference or an object which overloads glob dereferencing.
 
 =head2 FileHandle
 
-Accepts a glob reference which is an open file handle, any C<IO::Handle>
-Object or subclass, or an object which overloads glob dereferencing and
-returns a glob reference which is an open file handle.
+Accepts a glob reference which is an open file handle, any C<IO::Handle> Object
+or subclass, or an object which overloads glob dereferencing and returns a glob
+reference which is an open file handle.
 
 =head2 Object
 
@@ -576,8 +584,6 @@ Accepts any blessed object.
 
 Bugs may be submitted at L<https://github.com/houseabsolute/Specio/issues>.
 
-I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
-
 =head1 SOURCE
 
 The source code repository for Specio can be found at L<https://github.com/houseabsolute/Specio>.
@@ -588,7 +594,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 - 2019 by Dave Rolsky.
+This software is Copyright (c) 2012 - 2025 by Dave Rolsky.
 
 This is free software, licensed under:
 
